# capi-user-awareness
User Awareness Framework CAPI

# Test Environment(demo#1 version)

* TV Board used:
> 1. Kant M2 ATSC [To verify BLE and WiFi Sensors]
> 2. Frame TV (Factory Setting: model name -> LS03R) [To verify Light & Motion Sensors]

* Verified Image Path:
http://168.219.244.109/products/tv/archive/2019/MAIN2019/KantM2_ATSC/TIZEN-5.0-MAIN2019-KantM2-RELEASE_20190109.3/images/T-KTM2AKUC/TIZEN-5.0-MAIN2019-KantM2-RELEASE_20190109.3_T-KTM2AKUC.tar.gz

* TV Image info :
```
[Version]
Model=Tizen5/TV;
Build=latest;
Release=latest;
[Build]
Type=eng;
Date=20190108_221638;
Time=22:16:38;
Variant=NONE;
ID=latest;
 ```

### For verifying BLE operations,
**BLE Advertisement using nRF is used for BLE device detection**
We have used nRF connect application on Android to emulate Mobile side GATT scenario. In nRF connect application, do following:

```
1. Create advertiser
2. Set property connectable
3. Include TX power in Adv data 
4. Add manufacturer data as : Company Id: 0x0075, Data: 0X420D0101010100E45D75FDE345
```
For verifying WiFi operations,
```
1. Connect TV and mobile to same WiFi AP first
```

*Note: We have executed the Light and Motion operations on Frame TV*

**For debugging UA framework logs can be checked with below command:**
```
logger-mgr --filter UA_MANAGER UAM_API UA_CAPI UA_PLUGIN_BLE UA_PLUGIN_LIGHT UA_PLUGIN_WIFI UA_PLUGIN_MOTION
dlogutil -v threadtime UA_MANAGER UAM_API UA_CAPI UA_PLUGIN_BLE UA_PLUGIN_LIGHT UA_PLUGIN_WIFI UA_PLUGIN_MOTION
```` 

**Set Capability:**
```
setcap cap_net_admin,cap_net_raw,cap_sys_rawio+eip /usr/bin/ua-manager
/usr/share/security-config/set_capability
sync and reboot
``` 

# How to test UAFW

## 1. Initialze
```
saerome.kim@sx:~$ sdb shell ua-test

* User Awareness test application 
* Build On: Jan 29 2019  02:06:11

=================================================================
 Main
-----------------------------------------------------------------
 [  1] Init                                                    >
 --------------------------------------------------------------- 
 [ u ] Account [ ] 
 [ - ] Name [ ] 
 --------------------------------------------------------------- 
 [ - ] Addes Sensor(s) [ ] 
 --------------------------------------------------------------- 
 [ d ] Selected Device ID [ ] 
 --------------------------------------------------------------- 
 [ p ] Previous menu 
 [ m ] Show Menu 
 [ q ] Quit 
=================================================================
( 4923) >> 1
ua_initialize
 - ua_initialize() ret: [0x0] [UA_ERROR_NONE]
( 4923) >> 
=================================================================
 Main >> Init
-----------------------------------------------------------------
 [  1] Init                                                    >
 [  2] Devices                                                 >
 [  3] Users                                                   >
 [  4] Sensors                                                 >
 [  5] Detection                                               >
 --------------------------------------------------------------- 
 [ u ] Account [ ] 
 [ - ] Name [ ] 
 --------------------------------------------------------------- 
 [ - ] Addes Sensor(s) [ ] 
 --------------------------------------------------------------- 
 [ d ] Selected Device ID [ ] 
 --------------------------------------------------------------- 
 [ p ] Previous menu 
 [ m ] Show Menu 
 [ q ] Quit 
=================================================================
( 4923) >> 1

=================================================================
 Main >> Init >> Init
-----------------------------------------------------------------
 [  1] ua_monitor_create
 [  2] ua_monitor_destroy
 [  3] ua_monitor_set_absence_detected_cb
 [  4] ua_monitor_set_sensor_state_cb
 [  5] ua_monitor_unset_absence_detected_cb
 [  6] ua_monitor_unset_sensor_state_cb
 [  7] ua_enable_low_power_mode
 [  8] ua_disable_low_power_mode
 --------------------------------------------------------------- 
 [ u ] Account [ ] 
 [ - ] Name [ ] 
 --------------------------------------------------------------- 
 [ - ] Addes Sensor(s) [ ] 
 --------------------------------------------------------------- 
 [ d ] Selected Device ID [ ] 
 --------------------------------------------------------------- 
 [ p ] Previous menu 
 [ m ] Show Menu 
 [ q ] Quit 
=================================================================
( 5088) >> 1
ua_create_create
 - ua_create_create() ret: [0x0] [UA_ERROR_NONE]
( 5088) >> 3
ua_monitor_set_absence_detected_cb
 - ua_monitor_set_absence_detected_cb() ret: [0x0] [UA_ERROR_NONE]
( 5088) >> 4
ua_monitor_set_sensor_state_cb
 - ua_monitor_set_sensor_state_cb() ret: [0x0] [UA_ERROR_NONE]
( 5088) >> 
```

## 2. Add Devices (Example: Wi-Fi device)
```
=================================================================
 Main >> Init
-----------------------------------------------------------------
 [  1] Init                                                    >
 [  2] Devices                                                 >
 [  3] Users                                                   >
 [  4] Sensors                                                 >
 [  5] Detection                                               >
 --------------------------------------------------------------- 
 [ u ] Account [ ] 
 [ - ] Name [ ] 
 --------------------------------------------------------------- 
 [ - ] Addes Sensor(s) [BLE WIFI MOTION LIGHT  ] 
 --------------------------------------------------------------- 
 [ d ] Selected Device ID [ ] 
 --------------------------------------------------------------- 
 [ p ] Previous menu 
 [ m ] Show Menu 
 [ q ] Quit 
=================================================================
( 3717) >> 2

=================================================================
 Main >> Init >> Devices
-----------------------------------------------------------------
 [  1] ua_device_create
 [  2] ua_device_destroy
 [  3] ua_device_set_mac_type ()                               >
 [  4] ua_device_set_os_info ()                                >
 [  5] ua_device_set_mobile_id ()                              >
 [  6] ua_device_set_mac_address ()                            >
 [  7] ua_device_get_wifi_bssid
 [  8] ua_device_set_wifi_ipv4_address ()                      >
 [  9] ua_user_add_device
 [ 10] ua_user_remove_device
 [ 11] ua_device_get_handle_by_mac_address                     >
 [ 12] ua_device_get_handle_by_mobile_id                       >
 [ 13] ua_foreach_all_registered_dev_info
 [ 14] ua_foreach_registered_dev_info_by_user                  >
 --------------------------------------------------------------- 
 [ u ] Account [ ] 
 [ - ] Name [ ] 
 --------------------------------------------------------------- 
 [ - ] Addes Sensor(s) [BLE WIFI MOTION LIGHT  ] 
 --------------------------------------------------------------- 
 [ d ] Selected Device ID [ ] 
 --------------------------------------------------------------- 
 [ p ] Previous menu 
 [ m ] Show Menu 
 [ q ] Quit 
=================================================================
( 3717) >> 1
ua_device_create
 - ua_device_create() ret: [0x0] [UA_ERROR_NONE]
( 3717) >> 3

=================================================================
 Main >> Init >> Devices >> ua_device_set_mac_type
-----------------------------------------------------------------
 [  1] type (1:BT 2:BLE 3:Wi-Fi 4:Motion 5:Light 6:Audio) ()
 [  2] run
 --------------------------------------------------------------- 
 [ u ] Account [ ] 
 [ - ] Name [ ] 
 --------------------------------------------------------------- 
 [ - ] Addes Sensor(s) [BLE WIFI MOTION LIGHT  ] 
 --------------------------------------------------------------- 
 [ d ] Selected Device ID [ ] 
 --------------------------------------------------------------- 
 [ p ] Previous menu 
 [ m ] Show Menu 
 [ q ] Quit 
=================================================================
( 3717) >> 1

=================================================================
 Input [type (1:BT 2:BLE 3:Wi-Fi 4:Motion 5:Light 6:Audio)] data 
-----------------------------------------------------------------
 current = []
 new >> 3
OK.

=================================================================
 Main >> Init >> Devices >> ua_device_set_mac_type
-----------------------------------------------------------------
 [  1] type (1:BT 2:BLE 3:Wi-Fi 4:Motion 5:Light 6:Audio) (3)
 [  2] run
 --------------------------------------------------------------- 
 [ u ] Account [ ] 
 [ - ] Name [ ] 
 --------------------------------------------------------------- 
 [ - ] Addes Sensor(s) [BLE WIFI MOTION LIGHT  ] 
 --------------------------------------------------------------- 
 [ d ] Selected Device ID [ ] 
 --------------------------------------------------------------- 
 [ p ] Previous menu 
 [ m ] Show Menu 
 [ q ] Quit 
=================================================================
( 3717) >> 2
ua_device_set_mac_type
 - ua_device_set_mac_type() ret: [0x0] [UA_ERROR_NONE]
( 3717) >> p

=================================================================
 Main >> Init >> Devices
-----------------------------------------------------------------
 [  1] ua_device_create
 [  2] ua_device_destroy
 [  3] ua_device_set_mac_type (WIFI)                           >
 [  4] ua_device_set_os_info ()                                >
 [  5] ua_device_set_mobile_id ()                              >
 [  6] ua_device_set_mac_address ()                            >
 [  7] ua_device_get_wifi_bssid
 [  8] ua_device_set_wifi_ipv4_address ()                      >
 [  9] ua_user_add_device
 [ 10] ua_user_remove_device
 [ 11] ua_device_get_handle_by_mac_address                     >
 [ 12] ua_device_get_handle_by_mobile_id                       >
 [ 13] ua_foreach_all_registered_dev_info
 [ 14] ua_foreach_registered_dev_info_by_user                  >
 --------------------------------------------------------------- 
 [ u ] Account [ ] 
 [ - ] Name [ ] 
 --------------------------------------------------------------- 
 [ - ] Addes Sensor(s) [BLE WIFI MOTION LIGHT  ] 
 --------------------------------------------------------------- 
 [ d ] Selected Device ID [ ] 
 --------------------------------------------------------------- 
 [ p ] Previous menu 
 [ m ] Show Menu 
 [ q ] Quit 
=================================================================
( 3717) >> 4

=================================================================
 Main >> Init >> Devices >> ua_device_set_os_info
-----------------------------------------------------------------
 [  1] type (1:Tizen 2:Andorid 3:iOS) ()
 [  2] run
 --------------------------------------------------------------- 
 [ u ] Account [ ] 
 [ - ] Name [ ] 
 --------------------------------------------------------------- 
 [ - ] Addes Sensor(s) [BLE WIFI MOTION LIGHT  ] 
 --------------------------------------------------------------- 
 [ d ] Selected Device ID [ ] 
 --------------------------------------------------------------- 
 [ p ] Previous menu 
 [ m ] Show Menu 
 [ q ] Quit 
=================================================================
( 3717) >> 1

=================================================================
 Input [type (1:Tizen 2:Andorid 3:iOS)] data 
-----------------------------------------------------------------
 current = []
 new >> 2
OK.

=================================================================
 Main >> Init >> Devices >> ua_device_set_os_info
-----------------------------------------------------------------
 [  1] type (1:Tizen 2:Andorid 3:iOS) (2)
 [  2] run
 --------------------------------------------------------------- 
 [ u ] Account [ ] 
 [ - ] Name [ ] 
 --------------------------------------------------------------- 
 [ - ] Addes Sensor(s) [BLE WIFI MOTION LIGHT  ] 
 --------------------------------------------------------------- 
 [ d ] Selected Device ID [ ] 
 --------------------------------------------------------------- 
 [ p ] Previous menu 
 [ m ] Show Menu 
 [ q ] Quit 
=================================================================
( 3717) >> 2
ua_device_set_os_info
 - ua_device_set_os_info() ret: [0x0] [UA_ERROR_NONE]
( 3717) >> p

=================================================================
 Main >> Init >> Devices
-----------------------------------------------------------------
 [  1] ua_device_create
 [  2] ua_device_destroy
 [  3] ua_device_set_mac_type (WIFI)                           >
 [  4] ua_device_set_os_info (Android)                         >
 [  5] ua_device_set_mobile_id ()                              >
 [  6] ua_device_set_mac_address ()                            >
 [  7] ua_device_get_wifi_bssid
 [  8] ua_device_set_wifi_ipv4_address ()                      >
 [  9] ua_user_add_device
 [ 10] ua_user_remove_device
 [ 11] ua_device_get_handle_by_mac_address                     >
 [ 12] ua_device_get_handle_by_mobile_id                       >
 [ 13] ua_foreach_all_registered_dev_info
 [ 14] ua_foreach_registered_dev_info_by_user                  >
 --------------------------------------------------------------- 
 [ u ] Account [ ] 
 [ - ] Name [ ] 
 --------------------------------------------------------------- 
 [ - ] Addes Sensor(s) [BLE WIFI MOTION LIGHT  ] 
 --------------------------------------------------------------- 
 [ d ] Selected Device ID [ ] 
 --------------------------------------------------------------- 
 [ p ] Previous menu 
 [ m ] Show Menu 
 [ q ] Quit 
=================================================================
( 3717) >> 5

=================================================================
 Main >> Init >> Devices >> ua_device_set_mobile_id
-----------------------------------------------------------------
 [  1] mobile_id ()
 [  2] run
 --------------------------------------------------------------- 
 [ u ] Account [ ] 
 [ - ] Name [ ] 
 --------------------------------------------------------------- 
 [ - ] Addes Sensor(s) [BLE WIFI MOTION LIGHT  ] 
 --------------------------------------------------------------- 
 [ d ] Selected Device ID [ ] 
 --------------------------------------------------------------- 
 [ p ] Previous menu 
 [ m ] Show Menu 
 [ q ] Quit 
=================================================================
( 3717) >> 1

=================================================================
 Input [mobile_id] data 
-----------------------------------------------------------------
 current = []
 new >> 50:77:05:2A:01:E8
OK.

=================================================================
 Main >> Init >> Devices >> ua_device_set_mobile_id
-----------------------------------------------------------------
 [  1] mobile_id (50:77:05:2A:01:E8)
 [  2] run
 --------------------------------------------------------------- 
 [ u ] Account [ ] 
 [ - ] Name [ ] 
 --------------------------------------------------------------- 
 [ - ] Addes Sensor(s) [BLE WIFI MOTION LIGHT  ] 
 --------------------------------------------------------------- 
 [ d ] Selected Device ID [ ] 
 --------------------------------------------------------------- 
 [ p ] Previous menu 
 [ m ] Show Menu 
 [ q ] Quit 
=================================================================
( 3717) >> 2
ua_device_set_mobile_id
 - ua_device_set_mobile_id() ret: [0x0] [UA_ERROR_NONE]
( 3717) >> p

=================================================================
 Main >> Init >> Devices
-----------------------------------------------------------------
 [  1] ua_device_create
 [  2] ua_device_destroy
 [  3] ua_device_set_mac_type (WIFI)                           >
 [  4] ua_device_set_os_info (Android)                         >
 [  5] ua_device_set_mobile_id (50:77:05:2A:01:E8)             >
 [  6] ua_device_set_mac_address ()                            >
 [  7] ua_device_get_wifi_bssid
 [  8] ua_device_set_wifi_ipv4_address ()                      >
 [  9] ua_user_add_device
 [ 10] ua_user_remove_device
 [ 11] ua_device_get_handle_by_mac_address                     >
 [ 12] ua_device_get_handle_by_mobile_id                       >
 [ 13] ua_foreach_all_registered_dev_info
 [ 14] ua_foreach_registered_dev_info_by_user                  >
 --------------------------------------------------------------- 
 [ u ] Account [ ] 
 [ - ] Name [ ] 
 --------------------------------------------------------------- 
 [ - ] Addes Sensor(s) [BLE WIFI MOTION LIGHT  ] 
 --------------------------------------------------------------- 
 [ d ] Selected Device ID [ ] 
 --------------------------------------------------------------- 
 [ p ] Previous menu 
 [ m ] Show Menu 
 [ q ] Quit 
=================================================================
( 3717) >> 6

=================================================================
 Main >> Init >> Devices >> ua_device_set_mac_address
-----------------------------------------------------------------
 [  1] MAC ()
 [  2] run
 --------------------------------------------------------------- 
 [ u ] Account [ ] 
 [ - ] Name [ ] 
 --------------------------------------------------------------- 
 [ - ] Addes Sensor(s) [BLE WIFI MOTION LIGHT  ] 
 --------------------------------------------------------------- 
 [ d ] Selected Device ID [ ] 
 --------------------------------------------------------------- 
 [ p ] Previous menu 
 [ m ] Show Menu 
 [ q ] Quit 
=================================================================
( 3717) >> 1

=================================================================
 Input [MAC] data 
-----------------------------------------------------------------
 current = []
 new >> 24:18:1D:3A:D8:17
OK.

=================================================================
 Main >> Init >> Devices >> ua_device_set_mac_address
-----------------------------------------------------------------
 [  1] MAC (24:18:1D:3A:D8:17)
 [  2] run
 --------------------------------------------------------------- 
 [ u ] Account [ ] 
 [ - ] Name [ ] 
 --------------------------------------------------------------- 
 [ - ] Addes Sensor(s) [BLE WIFI MOTION LIGHT  ] 
 --------------------------------------------------------------- 
 [ d ] Selected Device ID [ ] 
 --------------------------------------------------------------- 
 [ p ] Previous menu 
 [ m ] Show Menu 
 [ q ] Quit 
=================================================================
( 3717) >> 2
ua_device_set_mac_address
 - ua_device_set_mac_address() ret: [0x0] [UA_ERROR_NONE]
( 3717) >> p

=================================================================
 Main >> Init >> Devices
-----------------------------------------------------------------
 [  1] ua_device_create
 [  2] ua_device_destroy
 [  3] ua_device_set_mac_type (WIFI)                           >
 [  4] ua_device_set_os_info (Android)                         >
 [  5] ua_device_set_mobile_id (50:77:05:2A:01:E8)             >
 [  6] ua_device_set_mac_address (24:18:1D:3A:D8:17)           >
 [  7] ua_device_get_wifi_bssid
 [  8] ua_device_set_wifi_ipv4_address ()                      >
 [  9] ua_user_add_device
 [ 10] ua_user_remove_device
 [ 11] ua_device_get_handle_by_mac_address                     >
 [ 12] ua_device_get_handle_by_mobile_id                       >
 [ 13] ua_foreach_all_registered_dev_info
 [ 14] ua_foreach_registered_dev_info_by_user                  >
 --------------------------------------------------------------- 
 [ u ] Account [ ] 
 [ - ] Name [ ] 
 --------------------------------------------------------------- 
 [ - ] Addes Sensor(s) [BLE WIFI MOTION LIGHT  ] 
 --------------------------------------------------------------- 
 [ d ] Selected Device ID [ ] 
 --------------------------------------------------------------- 
 [ p ] Previous menu 
 [ m ] Show Menu 
 [ q ] Quit 
=================================================================
( 3717) >> 9
ua_user_add_device
 - ua_user_add_device() ret: [0x0] [UA_ERROR_NONE]
( 3717) >> sensor: WIFI is Ready
```

## 3. How to check the added device list
```
=================================================================
 Main >> Init >> Devices >> ua_device_set_mac_address
-----------------------------------------------------------------
 [  1] MAC (24:18:1D:3A:D8:17)
 [  2] run
 --------------------------------------------------------------- 
 [ u ] Account [ ] 
 [ - ] Name [ ] 
 --------------------------------------------------------------- 
 [ - ] Addes Sensor(s) [BLE WIFI MOTION LIGHT  ] 
 --------------------------------------------------------------- 
 [ d ] Selected Device ID [ ] 
 --------------------------------------------------------------- 
 [ p ] Previous menu 
 [ m ] Show Menu 
 [ q ] Quit 
=================================================================
( 3717) >> 2

=================================================================
 Main >> Init >> Devices >> Select Device
-----------------------------------------------------------------
 [  1] Device list ()
 [  2] Apply
 --------------------------------------------------------------- 
 [ u ] Account [ ] 
 [ - ] Name [ ] 
 --------------------------------------------------------------- 
 [ - ] Addes Sensor(s) [BLE WIFI MOTION LIGHT  ] 
 --------------------------------------------------------------- 
 [ d ] Selected Device ID [ ] 
 --------------------------------------------------------------- 
 [ p ] Previous menu 
 [ m ] Show Menu 
 [ q ] Quit 
=================================================================
( 3717) >> 1
[1]
Device MAC Type : WIFI
Device OS Type : Android
Device Mobile ID : 50:77:05:2A:01:E8
Device MAC : 24:18:1D:3A:D8:17
Device BSSID : (null)
Device IPv4 Addr : 
Pairing Required : NO
( 3717) >> 
=================================================================
 Input [Device list] data 
-----------------------------------------------------------------
 current = []
 new >> 1
OK.

=================================================================
 Main >> Init >> Devices
-----------------------------------------------------------------
 [  1] ua_device_create
 [  2] ua_device_destroy
 [  3] ua_device_set_mac_type (WIFI)                           >
 [  4] ua_device_set_os_info (Android)                         >
 [  5] ua_device_set_mobile_id (50:77:05:2A:01:E8)             >
 [  6] ua_device_set_mac_address (24:18:1D:3A:D8:17)           >
 [  7] ua_device_get_wifi_bssid
 [  8] ua_device_set_wifi_ipv4_address ()                      >
 [  9] ua_user_add_device
 [ 10] ua_user_remove_device
 [ 11] ua_device_get_handle_by_mac_address                     >
 [ 12] ua_device_get_handle_by_mobile_id                       >
 [ 13] ua_foreach_all_registered_dev_info
 [ 14] ua_foreach_registered_dev_info_by_user                  >
 --------------------------------------------------------------- 
 [ u ] Account [ ] 
 [ - ] Name [ ] 
 --------------------------------------------------------------- 
 [ - ] Addes Sensor(s) [BLE WIFI MOTION LIGHT  ] 
 --------------------------------------------------------------- 
 [ d ] Selected Device ID [1 ] 
 --------------------------------------------------------------- 
 [ p ] Previous menu 
 [ m ] Show Menu 
 [ q ] Quit 
=================================================================
```

## 4. Remove device (Following step 3.)
```
=================================================================
 Main >> Init >> Devices
-----------------------------------------------------------------
 [  1] ua_device_create
 [  2] ua_device_destroy
 [  3] ua_device_set_mac_type (WIFI)                           >
 [  4] ua_device_set_os_info (Android)                         >
 [  5] ua_device_set_mobile_id (50:77:05:2A:01:E8)             >
 [  6] ua_device_set_mac_address (24:18:1D:3A:D8:17)           >
 [  7] ua_device_get_wifi_bssid
 [  8] ua_device_set_wifi_ipv4_address ()                      >
 [  9] ua_user_add_device
 [ 10] ua_user_remove_device
 [ 11] ua_device_get_handle_by_mac_address                     >
 [ 12] ua_device_get_handle_by_mobile_id                       >
 [ 13] ua_foreach_all_registered_dev_info
 [ 14] ua_foreach_registered_dev_info_by_user                  >
 --------------------------------------------------------------- 
 [ u ] Account [ ] 
 [ - ] Name [ ] 
 --------------------------------------------------------------- 
 [ - ] Addes Sensor(s) [BLE WIFI MOTION LIGHT  ] 
 --------------------------------------------------------------- 
 [ d ] Selected Device ID [1 ] 
 --------------------------------------------------------------- 
 [ p ] Previous menu 
 [ m ] Show Menu 
 [ q ] Quit 
=================================================================
( 3717) >> 10
ua_user_remove_device
 - ua_user_remove_device() ret: [0x0] [UA_ERROR_NONE]
( 3717) >> sensor: WIFI is Not Ready
```

## 5. Detect PRESENCE (Example. Wi-Fi)
```
=================================================================
 Main >> Init
-----------------------------------------------------------------
 [  1] Init                                                    >
 [  2] Devices                                                 >
 [  3] Users                                                   >
 [  4] Sensors                                                 >
 [  5] Detection                                               >
 --------------------------------------------------------------- 
 [ u ] Account [ ] 
 [ - ] Name [ ] 
 --------------------------------------------------------------- 
 [ - ] Addes Sensor(s) [BLE WIFI MOTION LIGHT  ] 
 --------------------------------------------------------------- 
 [ d ] Selected Device ID [ ] 
 --------------------------------------------------------------- 
 [ p ] Previous menu 
 [ m ] Show Menu 
 [ q ] Quit 
=================================================================
( 3717) >> 5

=================================================================
 Main >> Init >> Detection
-----------------------------------------------------------------
 [  1] ua_monitor_start_presence_detection                     >
 [  2] ua_monitor_stop_presence_detection
 [  3] ua_monitor_start_absence_detection                      >
 [  4] ua_monitor_stop_absence_detection
 --------------------------------------------------------------- 
 [ u ] Account [ ] 
 [ - ] Name [ ] 
 --------------------------------------------------------------- 
 [ - ] Addes Sensor(s) [BLE WIFI ] 
 --------------------------------------------------------------- 
 [ d ] Selected Device ID [ ] 
 --------------------------------------------------------------- 
 [ p ] Previous menu 
 [ m ] Show Menu 
 [ q ] Quit 
=================================================================
( 5088) >> 1

=================================================================
 Main >> Init >> Detection >> ua_monitor_start_presence_detection
-----------------------------------------------------------------
 [  1] type (1:ALL 2:ANY) (2)
 [  2] run
 --------------------------------------------------------------- 
 [ u ] Account [ ] 
 [ - ] Name [ ] 
 --------------------------------------------------------------- 
 [ - ] Addes Sensor(s) [BLE WIFI ] 
 --------------------------------------------------------------- 
 [ d ] Selected Device ID [ ] 
 --------------------------------------------------------------- 
 [ p ] Previous menu 
 [ m ] Show Menu 
 [ q ] Quit 
=================================================================
( 4478) >> 2
ua_monitor_start_presence_detection
 - ua_monitor_start_presence_detection() ret: [0x0] [UA_ERROR_NONE]
( 4478) >> result : UA_ERROR_NONE
sensor WIFI PRESENCE detected
User account info default@default.com
```

## 6. Detect ABSENCE (Example. Wi-Fi)
```
=================================================================
 Main >> Init >> Detection
-----------------------------------------------------------------
 [  1] ua_monitor_start_presence_detection                     >
 [  2] ua_monitor_stop_presence_detection
 [  3] ua_monitor_start_absence_detection                      >
 [  4] ua_monitor_stop_absence_detection
 --------------------------------------------------------------- 
 [ u ] Account [ ] 
 [ - ] Name [ ] 
 --------------------------------------------------------------- 
 [ - ] Addes Sensor(s) [BLE MOTION  ] 
 --------------------------------------------------------------- 
 [ d ] Selected Device ID [ ] 
 --------------------------------------------------------------- 
 [ p ] Previous menu 
 [ m ] Show Menu 
 [ q ] Quit 
=================================================================
( 4478) >> 2
ua_monitor_stop_presence_detectio
 - ua_monitor_stop_presence_detectio() ret: [0x0] [UA_ERROR_NONE]
( 4478) >> 3

=================================================================
 Main >> Init >> Detection >> ua_monitor_start_absence_detection
-----------------------------------------------------------------
 [  1] type (1:ALL 2:ANY) (2)
 [  2] run
 --------------------------------------------------------------- 
 [ u ] Account [ ] 
 [ - ] Name [ ] 
 --------------------------------------------------------------- 
 [ - ] Addes Sensor(s) [BLE MOTION  ] 
 --------------------------------------------------------------- 
 [ d ] Selected Device ID [ ] 
 --------------------------------------------------------------- 
 [ p ] Previous menu 
 [ m ] Show Menu 
 [ q ] Quit 
=================================================================
( 4478) >> 2
ua_monitor_start_absence_detection
 - ua_monitor_start_absence_detection() ret: [0x0] [UA_ERROR_NONE]

( 4478) >> result : UA_ERROR_NONE
sensor WIFI ABSENCE detected
User account info default@default.com
absence all detected
```

# Trouble shooting
###### 1. If get_default user command fails
- Execute 'get_default_user'
```sh
tc_usage_print:828() Key 21 : usage Get default user) 
```
- OUTPUT
```sh
test_input_callback:499() returns UA_ERROR_NONE
test_input_callback:505() ua_user_get_account returned : UA_ERROR_NONE
test_input_callback:507() User account info default@default.com
```
- Solution 
```sh
STEP 1. remove DB first 
sh-3.2# rm -f /opt/usr/dbspace/.ua-manager-data.db*

STEP 2. re-install ua-manager RPMs

STEP 3. set capabilities
sh-3.2# setcap cap_net_admin,cap_net_raw,cap_sys_rawio+eip /usr/bin/ua-manager
sh-3.2# /usr/share/security-config/set_capability

STEP 4. sync & reboot
```


